<template>
	<div class="section-main-container layout-padding">
		<div class="section-main-padding layout-padding-auto layout-padding-view">
			<div class="section-user-search mb15">
				<el-form :inline="true" :model="state.tableData.param" class="demo-form-inline" label-position="left"
					size="default" @submit.prevent>
					<el-form-item label="人员姓名">
						<el-input v-model="state.tableData.param.employeeName" placeholder="请输入人员姓名" clearable
							@keyup.enter="getTableData" style="max-width: 180px" />
					</el-form-item>
					<el-form-item label="公司名称">
						<el-input v-model="state.tableData.param.companyName" placeholder="请输入公司名称" clearable
							@keyup.enter="getTableData" style="max-width: 180px" />
					</el-form-item>
					<el-form-item label="驻勤点名称">
						<el-input v-model="state.tableData.param.railReferenceName" placeholder="请输入驻勤点名称" clearable
							@keyup.enter="getTableData" style="max-width: 180px" />
					</el-form-item>

					<el-form-item label="监管机构">
						<!-- <el-select v-model="state.tableData.param.superviseDepartId" placeholder="请选择" style="width: 100%;">
							<el-option label="" value="" />
						</el-select> -->
						<el-cascader v-model="state.tableData.param.superviseDepartIdArr" :options="state.tableData.param.options"
							:props="customProps" collapse-tags collapse-tags-tooltip :show-all-levels="false" clearable
							ref="myCascader" />
					</el-form-item>

					<el-form-item label="证件号">
						<el-input v-model="state.tableData.param.employeeIdCardNo" placeholder="请输入人员身份证号" clearable
							@keyup.enter="getTableData" style="max-width: 180px" />
					</el-form-item>

					<el-form-item label="日期">
						<el-date-picker v-model="state.tableData.param.eventStarEndDate" type="daterange" range-separator="-"
							start-placeholder="开始日期" end-placeholder="结束日期" format="YYYY-MM-DD" value-format="YYYY-MM-DD" />
					</el-form-item>


					<el-form-item>
						<el-button type="primary" @click="getTableData">查询</el-button>
						<el-button type="default" @click="resetgetTableData">重置</el-button>
						<el-button type="primary" @click="exportData">导出</el-button>
					</el-form-item>
				</el-form>

			</div>
			<el-table :data="state.tableData.data" v-loading="state.tableData.loading" style="width: 100%">
				<el-table-column label="序号" width="60">
					<template #default="scope">
						{{ scope.$index + 1 + (state.tableData.param.pageIndex - 1) * state.tableData.param.pageSize }}
					</template>
				</el-table-column>
				<el-table-column prop="eventDate" label="告警时间" width="180" show-overflow-tooltip></el-table-column>
				<el-table-column prop="railRuleTypeText" label="告警类型" width="100" show-overflow-tooltip></el-table-column>
				<el-table-column prop="stationRailName" label="围栏名称" width="100" show-overflow-tooltip></el-table-column>

				<el-table-column prop="employeeName" label="姓名" width="80" show-overflow-tooltip></el-table-column>
				<el-table-column prop="employeeIdCardNo" label="身份证号" width="230">
					<template #default="scope">
						<span class="idCarNoSpan"><em>{{
							scope.row.showidCardNo ? scope.row.employeeIdCardNo :
							scope.row.employeeIdCardNo.replace(/^(.{3})(?:\d+)(.{4})$/,
								"$1******$2")
						}}</em><el-button link type="primary" size="small" @click="idCardNoBtn(scope.row)">{{
	scope.row.showidCardNo ? '隐藏' : '显示' }}</el-button></span>
					</template>
				</el-table-column>
				<el-table-column prop="companyName" label="公司名称" show-overflow-tooltip></el-table-column>
				<el-table-column prop="rail_reference_name" label="驻勤点名称" show-overflow-tooltip></el-table-column>
				<el-table-column prop="rail_reference_address" label="驻勤点地址" show-overflow-tooltip></el-table-column>
				<el-table-column prop="rail_reference_supervise_depart_name" label="驻勤点监管机构"
					show-overflow-tooltip></el-table-column>

			</el-table>
			<el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" class="mt15"
				:pager-count="5" :page-sizes="[10, 20, 30, 100, 200, 300, 1000]"
				v-model:current-page="state.tableData.param.pageIndex" background
				v-model:page-size="state.tableData.param.pageSize" layout="total, sizes, prev, pager, next, jumper"
				:total="state.tableData.total">
			</el-pagination>
		</div>
		<!-- <ConfigDialog ref="configDialogRef" @refresh="getTableData()" /> -->
	</div>
</template>

<script setup lang="ts" name="railAlarm">
import { defineAsyncComponent, reactive, onMounted, ref, toRaw, nextTick } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import { ConfigApi } from '/@/api/api'
import { useRoute, useRouter, onBeforeRouteUpdate } from 'vue-router';
import { refreshBtnView } from '/@/components/refreshView'
import { log } from 'console';
import { Session } from '/@/utils/storage';
// 引入组件
// const ConfigDialog = defineAsyncComponent(() => import('./dialog.vue'));
// 定义变量内容
const customProps = {
	multiple: true,// 启用多选
	checkStrictly: false,//父子节点不互相关联
	emitPath: true,//若设置 false，则只返回该节点的值
	value: 'code',//自定义当前数组的键名 - value
	label: 'name', // 自定义当前数组的键名 - label 
}
const route = useRoute()
const configDialogRef = ref();
const myCascader = ref();
const state = reactive({
	tableData: {
		data: [],
		total: 0,
		loading: false,
		param: {
			pageIndex: 1,
			pageSize: 10,
			employeeName: '',
			companyName: '',
			railReferenceName: '',
			superviseDepartIds: [],
			superviseDepartIdArr: [],
			employeeIdCardNo: '',
			eventStarEndDate: [] as string[],
			eventStartDate: '',
			eventEndDate: '',
			options: []
		},
	},
	RestesteventStarEndDate: [] as string[],
	RestesteventStartDate: '',
	RestesteventEndDate: '',
});
//查询监管机构
const searchDeparts = () => {
	ConfigApi().searchDepartsApi({deskTypes: Session.get('platform')==='2' ? ['Proprietor'] : Session.get('platform')==='3' ? ["TemporarySecurity"] : ['Normal']}).then(response => {
		console.log('response查询00', response)
		console.log('response.data00', response.data)
		if (response.status == 200) {
			let data = response.data;
			console.log(data)
			state.tableData.param.options = data;
			// state.tableData.data = response.data.data
			// state.tableData.total = response.data.totalCount;
		}
	})
}
// 初始化表格数据
const getTableData = () => {
	// debugger
	// console.log(state.tableData.param.superviseDepartIdArr)
	console.log('myCascader', myCascader.value.getCheckedNodes())
	let Depstr: [] = []
	if (myCascader.value.getCheckedNodes().length) {
		myCascader.value.getCheckedNodes().forEach(item => Depstr.push(item.value))
	}
	state.tableData.param.superviseDepartIds = Depstr
	// let sdepatId = toRaw(state.tableData.param.superviseDepartIds)
	// console.log('sdepatId', sdepatId)
	state.tableData.loading = true;
	let obj = state.tableData.param
	if (obj.eventStarEndDate) {
		obj.eventStartDate = obj.eventStarEndDate[0]
		obj.eventEndDate = obj.eventStarEndDate[1]
	}
	let obj2 = JSON.parse(JSON.stringify(obj))
	delete obj2.options
	delete obj2.superviseDepartIdArr
	delete obj2.eventStarEndDate
	obj2.deskTypes = Session.get('platform')==='2' ? ['Proprietor'] : Session.get('platform')==='3' ? ["TemporarySecurity"] : ['Normal']
	ConfigApi().railAlarmSearchApi(obj2).then(response => {
		console.log('response查询11', response)
		console.log('response.data', response.data)
		if (response.status == 200) {
			state.tableData.data = response.data.data
			state.tableData.total = response.data.totalCount;
			if (state.tableData.data?.length) {
				state.tableData.data.forEach((item) => {
					item.showidCardNo = false
				})
			}
		}
	})
	setTimeout(() => {
		state.tableData.loading = false;
	}, 500);
};
//重置
const resetgetTableData = () => {
	if (myCascader.value.getCheckedNodes().length) {
		myCascader.value.$refs.panel.clearCheckedNodes()//重置el-cascader
	}
	let obj = {
		pageIndex: 1,
		pageSize: 10,
		employeeName: '',
		companyName: '',
		railReferenceName: '',
		superviseDepartIds: [],
		superviseDepartIdArr: [],
		employeeIdCardNo: '',
		eventStarEndDate: state.RestesteventStarEndDate,
		eventStartDate: state.RestesteventStartDate,
		eventEndDate: state.RestesteventEndDate,
		options: state.tableData.param.options
	}
	state.tableData.param = reactive(obj)
	getTableData()
};
// 分页改变
const onHandleSizeChange = (val: number) => {
	state.tableData.param.pageSize = val;
	getTableData();
};
// 分页改变
const onHandleCurrentChange = (val: number) => {
	state.tableData.param.pageIndex = val;
	getTableData();
};
//刷新当前列表
// const reload = inject('reload')//子接收
const refreshBtn = () => {
	refreshBtnView(route)
}
//显示隐藏身份证号
const idCardNoBtn = (row) => {
	console.log(row)
	row.showidCardNo = !row.showidCardNo
}
//导出excel
const exportData = () => {
	let Depstr: [] = [];
	if (myCascader.value.getCheckedNodes().length) {
		myCascader.value.getCheckedNodes().forEach(item => Depstr.push(item.value))
	}
	state.tableData.param.superviseDepartIds = Depstr
	let obj = JSON.parse(JSON.stringify(state.tableData.param))
	if (obj.eventStarEndDate) {
		obj.eventStartDate = (obj.eventStarEndDate)[0]
		obj.eventEndDate = (obj.eventStarEndDate)[1]
	} else {
		ElMessage.error('请选择日期');
		return
	}

	delete obj.options
	delete obj.superviseDepartIdArr
	delete obj.eventStarEndDate
	delete obj.pageIndex
	delete obj.pageSize
	state.tableData.loading = true;
	obj.deskTypes = Session.get('platform')==='2' ? ['Proprietor'] : Session.get('platform')==='3' ? ["TemporarySecurity"] : ['Normal']
	ConfigApi().exportRailMessageApi(obj).then(response => {
		setTimeout(() => {
			state.tableData.loading = false;
			getTableData()
		}, 500);
		const content = response;
		const blob = new Blob([content]);
		const fileName = `围栏告警.xlsx`;
		if ("download" in document.createElement("a")) {
			// 非IE下载
			const elink = document.createElement("a");
			elink.download = fileName;
			elink.style.display = "none";
			elink.href = URL.createObjectURL(blob);
			document.body.appendChild(elink);
			elink.click();
			URL.revokeObjectURL(elink.href); // 释放URL 对象
			document.body.removeChild(elink);
		} else {
			// IE10+下载
			navigator.msSaveBlob(blob, fileName);
		}
	}).catch((error) => { })
}
// 页面加载时
onMounted(() => {
	var tempDate = new Date() // 获取今天的日期
	let nowDate = tempDate.getFullYear() + '-' + (tempDate.getMonth() + 1 < 10 ? '0' + (tempDate.getMonth() + 1) : tempDate.getMonth() + 1) + '-' + (tempDate.getDate() < 10 ? '0' + tempDate.getDate() : tempDate.getDate())
	tempDate.setDate(tempDate.getDate() - 6) // 今天的前N天的日期，N自定义
	var endDate = tempDate.getFullYear() + '-' + (tempDate.getMonth() + 1 < 10 ? '0' + (tempDate.getMonth() + 1) : tempDate.getMonth() + 1) + '-' + (tempDate.getDate() < 10 ? '0' + tempDate.getDate() : tempDate.getDate())
	console.log('endDate', endDate)
	state.RestesteventStarEndDate = ['' + endDate + '', '' + nowDate + '']
	state.RestesteventStartDate = endDate
	state.RestesteventEndDate = nowDate
	state.tableData.param.eventStarEndDate = ['' + endDate + '', '' + nowDate + '']//获取当前日期与前6天日期['2023-03-24','2023-03-30']
	searchDeparts();//查询监管机构
	// getTableData();
});
</script>

<style scoped lang="scss">
.section-main-container {
	.section-main-padding {
		padding: 15px;

		.el-table {
			flex: 1;
		}

	}

	.idCarNoSpan {
		display: flex;

		em {
			font-style: normal;
			margin-right: 20px;
		}
	}
}
</style>
